ELEMENTS = {
    "H": {"covalent_radius": 0.31, "color": "white", "size": 5},
    "He": {"covalent_radius": 0.28, "color": "cyan", "size": 5},
    "Li": {"covalent_radius": 1.28, "color": "purple", "size": 8},
    "Be": {"covalent_radius": 0.96, "color": "darkgreen", "size": 8},
    "B": {"covalent_radius": 0.84, "color": "pink", "size": 8},
    "C": {"covalent_radius": 0.76, "color": "rgb(48,48,48)", "size": 10},
    "N": {"covalent_radius": 0.71, "color": "blue", "size": 10},
    "O": {"covalent_radius": 0.66, "color": "red", "size": 10},
    "F": {"covalent_radius": 0.57, "color": "green", "size": 8},
    "Ne": {"covalent_radius": 0.58, "color": "cyan", "size": 5},
    "Na": {"covalent_radius": 1.66, "color": "blue", "size": 8},
    "Mg": {"covalent_radius": 1.41, "color": "lightgreen", "size": 10},
    "Al": {"covalent_radius": 1.21, "color": "gray", "size": 10},
    "Si": {"covalent_radius": 1.11, "color": "lightgray", "size": 10},
    "P": {"covalent_radius": 1.07, "color": "orange", "size": 12},
    "S": {"covalent_radius": 1.05, "color": "yellow", "size": 10},
    "Cl": {"covalent_radius": 1.02, "color": "green", "size": 10},
    "Ar": {"covalent_radius": 1.06, "color": "cyan", "size": 5},
    "K": {"covalent_radius": 2.03, "color": "violet", "size": 12},
    "Ca": {"covalent_radius": 1.76, "color": "lightblue", "size": 12},
    "Sc": {"covalent_radius": 1.70, "color": "gray", "size": 12},
    "Ti": {"covalent_radius": 1.60, "color": "gray", "size": 12},
    "V": {"covalent_radius": 1.53, "color": "gray", "size": 12},
    "Cr": {"covalent_radius": 1.39, "color": "gray", "size": 12},
    "Mn": {"covalent_radius": 1.39, "color": "gray", "size": 12},
    "Fe": {"covalent_radius": 1.32, "color": "darkorange", "size": 12},
    "Co": {"covalent_radius": 1.26, "color": "crimson", "size": 15},
    "Ni": {"covalent_radius": 1.24, "color": "bluegray", "size": 12},
    "Cu": {"covalent_radius": 1.32, "color": "brown", "size": 12},
    "Zn": {"covalent_radius": 1.22, "color": "lightblue", "size": 12},
    "Ga": {"covalent_radius": 1.22, "color": "lightblue", "size": 12},
    "Ge": {"covalent_radius": 1.20, "color": "lightgray", "size": 12},
    "As": {"covalent_radius": 1.19, "color": "bluegray", "size": 12},
    "Se": {"covalent_radius": 1.20, "color": "yellow", "size": 12},
    "Br": {"covalent_radius": 1.20, "color": "darkred", "size": 12},
    "Kr": {"covalent_radius": 1.16, "color": "cyan", "size": 5},
    "Rb": {"covalent_radius": 2.20, "color": "violet", "size": 14},
    "Sr": {"covalent_radius": 1.95, "color": "lightblue", "size": 14},
    "Y": {"covalent_radius": 1.90, "color": "gray", "size": 14},
    "Zr": {"covalent_radius": 1.75, "color": "gray", "size": 14},
    "Nb": {"covalent_radius": 1.64, "color": "gray", "size": 14},
    "Mo": {"covalent_radius": 1.54, "color": "gray", "size": 14},
    "Tc": {"covalent_radius": 1.47, "color": "gray", "size": 14},
    "Ru": {"covalent_radius": 1.46, "color": "gray", "size": 14},
    "Rh": {"covalent_radius": 1.42, "color": "gray", "size": 14},
    "Pd": {"covalent_radius": 1.39, "color": "seagreen", "size": 14},
    "Pt": {"covalent_radius": 1.36, "color": "white", "size": 14},
    "Ag": {"covalent_radius": 1.45, "color": "gray", "size": 14},
    "Cd": {"covalent_radius": 1.44, "color": "lightblue", "size": 14},
    "In": {"covalent_radius": 1.42, "color": "gray", "size": 14},
    "Sn": {"covalent_radius": 1.39, "color": "lightgray", "size": 14},
    "Sb": {"covalent_radius": 1.39, "color": "bluegray", "size": 14},
    "Te": {"covalent_radius": 1.38, "color": "yellow", "size": 14},
    "I": {"covalent_radius": 1.39, "color": "purple", "size": 14},
    "Xe": {"covalent_radius": 1.40, "color": "cyan", "size": 5},
    "Cs": {"covalent_radius": 2.44, "color": "violet", "size": 16},
    "Ba": {"covalent_radius": 2.15, "color": "lightblue", "size": 16},
    "La": {"covalent_radius": 2.07, "color": "gray", "size": 16},
    "Ce": {"covalent_radius": 2.04, "color": "gray", "size": 16},
    "Pr": {"covalent_radius": 2.03, "color": "gray", "size": 16},
    "Nd": {"covalent_radius": 2.01, "color": "gray", "size": 16},
    "Pm": {"covalent_radius": 1.99, "color": "gray", "size": 16},
    "Sm": {"covalent_radius": 1.98, "color": "gray", "size": 16},
    "Eu": {"covalent_radius": 1.98, "color": "gray", "size": 16},
    "Gd": {"covalent_radius": 1.96, "color": "gray", "size": 16},
    "Tb": {"covalent_radius": 1.94, "color": "gray", "size": 16},
    "Dy": {"covalent_radius": 1.92, "color": "gray", "size": 16},
    "Ho": {"covalent_radius": 1.92, "color": "gray", "size": 16},
    "Er": {"covalent_radius": 1.89, "color": "gray", "size": 16},
    "Tm": {"covalent_radius": 1.90, "color": "gray", "size": 16},
    "Yb": {"covalent_radius": 1.87, "color": "gray", "size": 16},
    "Lu": {"covalent_radius": 1.87, "color": "gray", "size": 16},
}
